@@ -176,10 +176,13 @@ class TestVideoFrameNdarray(TestCase):
             self.assertTrue((frame.to_ndarray() == array).all())
 
     def test_ndarray_gray_align(self):
+        array = numpy.random.randint(0, 256, size=(238, 318), dtype=numpy.uint8)
         for format in ['gray', 'gray8']:
-            frame = VideoFrame(318, 238, format=format)
-            array = frame.to_ndarray()
-            self.assertEqual(array.shape, (238, 318))
+            frame = VideoFrame.from_ndarray(array, format=format)
+            self.assertEqual(frame.width, 318)
+            self.assertEqual(frame.height, 238)
+            self.assertEqual(frame.format.name, 'gray')
+            self.assertTrue((frame.to_ndarray() == array).all())
 
     def test_ndarray_rgb(self):
         array = numpy.random.randint(0, 256, size=(480, 640, 3), dtype=numpy.uint8)
@@ -191,10 +194,13 @@ class TestVideoFrameNdarray(TestCase):
             self.assertTrue((frame.to_ndarray() == array).all())
 
     def test_ndarray_rgb_align(self):
+        array = numpy.random.randint(0, 256, size=(238, 318, 3), dtype=numpy.uint8)
         for format in ['rgb24', 'bgr24']:
-            frame = VideoFrame(318, 238, format=format)
-            array = frame.to_ndarray()
-            self.assertEqual(array.shape, (238, 318, 3))
+            frame = VideoFrame.from_ndarray(array, format=format)
+            self.assertEqual(frame.width, 318)
+            self.assertEqual(frame.height, 238)
+            self.assertEqual(frame.format.name, format)
+            self.assertTrue((frame.to_ndarray() == array).all())
 
     def test_ndarray_rgba(self):
         array = numpy.random.randint(0, 256, size=(480, 640, 4), dtype=numpy.uint8)
@@ -206,10 +212,13 @@ class TestVideoFrameNdarray(TestCase):
             self.assertTrue((frame.to_ndarray() == array).all())
 
     def test_ndarray_rgba_align(self):
+        array = numpy.random.randint(0, 256, size=(238, 318, 4), dtype=numpy.uint8)
         for format in ['argb', 'rgba', 'abgr', 'bgra']:
-            frame = VideoFrame(318, 238, format=format)
-            array = frame.to_ndarray()
-            self.assertEqual(array.shape, (238, 318, 4))
+            frame = VideoFrame.from_ndarray(array, format=format)
+            self.assertEqual(frame.width, 318)
+            self.assertEqual(frame.height, 238)
+            self.assertEqual(frame.format.name, format)
+            self.assertTrue((frame.to_ndarray() == array).all())
 
     def test_ndarray_yuv420p(self):
         array = numpy.random.randint(0, 256, size=(720, 640), dtype=numpy.uint8)
@@ -220,9 +229,12 @@ class TestVideoFrameNdarray(TestCase):
         self.assertTrue((frame.to_ndarray() == array).all())
 
     def test_ndarray_yuv420p_align(self):
-        frame = VideoFrame(318, 238, format='yuv420p')
-        array = frame.to_ndarray()
-        self.assertEqual(array.shape, (357, 318))
+        array = numpy.random.randint(0, 256, size=(357, 318), dtype=numpy.uint8)
+        frame = VideoFrame.from_ndarray(array, format='yuv420p')
+        self.assertEqual(frame.width, 318)
+        self.assertEqual(frame.height, 238)
+        self.assertEqual(frame.format.name, 'yuv420p')
+        self.assertTrue((frame.to_ndarray() == array).all())
 
     def test_ndarray_yuyv422(self):
         array = numpy.random.randint(0, 256, size=(480, 640, 2), dtype=numpy.uint8)
@@ -233,9 +245,12 @@ class TestVideoFrameNdarray(TestCase):
         self.assertTrue((frame.to_ndarray() == array).all())
 
     def test_ndarray_yuyv422_align(self):
-        frame = VideoFrame(318, 238, format='yuyv422')
-        array = frame.to_ndarray()
-        self.assertEqual(array.shape, (238, 318, 2))
+        array = numpy.random.randint(0, 256, size=(238, 318, 2), dtype=numpy.uint8)
+        frame = VideoFrame.from_ndarray(array, format='yuyv422')
+        self.assertEqual(frame.width, 318)
+        self.assertEqual(frame.height, 238)
+        self.assertEqual(frame.format.name, 'yuyv422')
+        self.assertTrue((frame.to_ndarray() == array).all())
 
 
 class TestVideoFrameTiming(TestCase):
